@@ -8,6 +8,8 @@ Usage::
     from mypy_boto3_accessanalyzer import (
         AccessAnalyzerClient,
         Client,
+        ListAccessPreviewFindingsPaginator,
+        ListAccessPreviewsPaginator,
         ListAnalyzedResourcesPaginator,
         ListAnalyzersPaginator,
         ListArchiveRulesPaginator,
@@ -19,6 +21,8 @@ Usage::
     client: AccessAnalyzerClient = boto3.client("accessanalyzer")
     session_client: AccessAnalyzerClient = session.client("accessanalyzer")
 
+    list_access_preview_findings_paginator: ListAccessPreviewFindingsPaginator = client.get_paginator("list_access_preview_findings")
+    list_access_previews_paginator: ListAccessPreviewsPaginator = client.get_paginator("list_access_previews")
     list_analyzed_resources_paginator: ListAnalyzedResourcesPaginator = client.get_paginator("list_analyzed_resources")
     list_analyzers_paginator: ListAnalyzersPaginator = client.get_paginator("list_analyzers")
     list_archive_rules_paginator: ListArchiveRulesPaginator = client.get_paginator("list_archive_rules")
@@ -27,6 +31,8 @@ Usage::
 """
 from mypy_boto3_accessanalyzer.client import AccessAnalyzerClient
 from mypy_boto3_accessanalyzer.paginator import (
+    ListAccessPreviewFindingsPaginator,
+    ListAccessPreviewsPaginator,
     ListAnalyzedResourcesPaginator,
     ListAnalyzersPaginator,
     ListArchiveRulesPaginator,
@@ -39,6 +45,8 @@ Client = AccessAnalyzerClient
 __all__ = (
     "AccessAnalyzerClient",
     "Client",
+    "ListAccessPreviewFindingsPaginator",
+    "ListAccessPreviewsPaginator",
     "ListAnalyzedResourcesPaginator",
     "ListAnalyzersPaginator",
     "ListArchiveRulesPaginator",
