@@ -8,6 +8,8 @@ Usage::
 
     from mypy_boto3_accessanalyzer import AccessAnalyzerClient
     from mypy_boto3_accessanalyzer.paginator import (
+        ListAccessPreviewFindingsPaginator,
+        ListAccessPreviewsPaginator,
         ListAnalyzedResourcesPaginator,
         ListAnalyzersPaginator,
         ListArchiveRulesPaginator,
@@ -16,6 +18,8 @@ Usage::
 
     client: AccessAnalyzerClient = boto3.client("accessanalyzer")
 
+    list_access_preview_findings_paginator: ListAccessPreviewFindingsPaginator = client.get_paginator("list_access_preview_findings")
+    list_access_previews_paginator: ListAccessPreviewsPaginator = client.get_paginator("list_access_previews")
     list_analyzed_resources_paginator: ListAnalyzedResourcesPaginator = client.get_paginator("list_analyzed_resources")
     list_analyzers_paginator: ListAnalyzersPaginator = client.get_paginator("list_analyzers")
     list_archive_rules_paginator: ListArchiveRulesPaginator = client.get_paginator("list_archive_rules")
@@ -29,6 +33,8 @@ from botocore.paginate import Paginator as Boto3Paginator
 
 from mypy_boto3_accessanalyzer.type_defs import (
     CriterionTypeDef,
+    ListAccessPreviewFindingsResponseTypeDef,
+    ListAccessPreviewsResponseTypeDef,
     ListAnalyzedResourcesResponseTypeDef,
     ListAnalyzersResponseTypeDef,
     ListArchiveRulesResponseTypeDef,
@@ -44,6 +50,8 @@ else:
 
 
 __all__ = (
+    "ListAccessPreviewFindingsPaginator",
+    "ListAccessPreviewsPaginator",
     "ListAnalyzedResourcesPaginator",
     "ListAnalyzersPaginator",
     "ListArchiveRulesPaginator",
@@ -51,9 +59,39 @@ __all__ = (
 )
 
 
+class ListAccessPreviewFindingsPaginator(Boto3Paginator):
+    """
+    [Paginator.ListAccessPreviewFindings documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.26/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAccessPreviewFindings)
+    """
+
+    def paginate(
+        self,
+        accessPreviewId: str,
+        analyzerArn: str,
+        filter: Dict[str, "CriterionTypeDef"] = None,
+        PaginationConfig: PaginatorConfigTypeDef = None,
+    ) -> Iterator[ListAccessPreviewFindingsResponseTypeDef]:
+        """
+        [ListAccessPreviewFindings.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.26/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAccessPreviewFindings.paginate)
+        """
+
+
+class ListAccessPreviewsPaginator(Boto3Paginator):
+    """
+    [Paginator.ListAccessPreviews documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.26/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAccessPreviews)
+    """
+
+    def paginate(
+        self, analyzerArn: str, PaginationConfig: PaginatorConfigTypeDef = None
+    ) -> Iterator[ListAccessPreviewsResponseTypeDef]:
+        """
+        [ListAccessPreviews.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.26/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAccessPreviews.paginate)
+        """
+
+
 class ListAnalyzedResourcesPaginator(Boto3Paginator):
     """
-    [Paginator.ListAnalyzedResources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.21/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAnalyzedResources)
+    [Paginator.ListAnalyzedResources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.26/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAnalyzedResources)
     """
 
     def paginate(
@@ -71,13 +109,13 @@ class ListAnalyzedResourcesPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListAnalyzedResourcesResponseTypeDef]:
         """
-        [ListAnalyzedResources.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.21/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAnalyzedResources.paginate)
+        [ListAnalyzedResources.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.26/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAnalyzedResources.paginate)
         """
 
 
 class ListAnalyzersPaginator(Boto3Paginator):
     """
-    [Paginator.ListAnalyzers documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.21/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAnalyzers)
+    [Paginator.ListAnalyzers documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.26/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAnalyzers)
     """
 
     def paginate(
@@ -86,26 +124,26 @@ class ListAnalyzersPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListAnalyzersResponseTypeDef]:
         """
-        [ListAnalyzers.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.21/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAnalyzers.paginate)
+        [ListAnalyzers.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.26/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAnalyzers.paginate)
         """
 
 
 class ListArchiveRulesPaginator(Boto3Paginator):
     """
-    [Paginator.ListArchiveRules documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.21/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListArchiveRules)
+    [Paginator.ListArchiveRules documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.26/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListArchiveRules)
     """
 
     def paginate(
         self, analyzerName: str, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListArchiveRulesResponseTypeDef]:
         """
-        [ListArchiveRules.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.21/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListArchiveRules.paginate)
+        [ListArchiveRules.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.26/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListArchiveRules.paginate)
         """
 
 
 class ListFindingsPaginator(Boto3Paginator):
     """
-    [Paginator.ListFindings documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.21/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListFindings)
+    [Paginator.ListFindings documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.26/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListFindings)
     """
 
     def paginate(
@@ -116,5 +154,5 @@ class ListFindingsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListFindingsResponseTypeDef]:
         """
-        [ListFindings.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.21/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListFindings.paginate)
+        [ListFindings.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.26/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListFindings.paginate)
         """
